aboutsummaryrefslogtreecommitdiff
path: root/src/patch/grid.hh
diff options
context:
space:
mode:
authorjthorn <jthorn@f88db872-0e4f-0410-b76b-b9085cfa78c5>2001-07-18 12:53:15 +0000
committerjthorn <jthorn@f88db872-0e4f-0410-b76b-b9085cfa78c5>2001-07-18 12:53:15 +0000
commitcf19ae9b588fe1c4a6933259de4e500eeedda1ba (patch)
tree533a8a479d20f8ad91a8ea23d930fd7c10dba008 /src/patch/grid.hh
parent624e1dfcbb8b0d5bd416485d7531fb952c42f3aa (diff)
rename full_grid__* --> ghosted_grid_
git-svn-id: http://svn.einsteintoolkit.org/cactus/EinsteinAnalysis/AHFinderDirect/trunk@217 f88db872-0e4f-0410-b76b-b9085cfa78c5
Diffstat (limited to 'src/patch/grid.hh')
-rw-r--r--src/patch/grid.hh101
1 files changed, 52 insertions, 49 deletions
diff --git a/src/patch/grid.hh b/src/patch/grid.hh
index 4aecdf2..fbdf2c7 100644
--- a/src/patch/grid.hh
+++ b/src/patch/grid.hh
@@ -33,10 +33,11 @@
// the derived class grid deals with the floating-point coordinates
// related to those subscripts.
//
// The grid has a nominal extent, surrounded by a "ghost zone" for
// finite differencing purposes. For simplicity, all grid functions
// (gridfns) are stored on the full grid (nominal + ghost zone), even
// though we actually only need this for finite differencing targets.
//
// We identify a gridfn by a small-integer "grid function number",
// a.k.a. "gfn". Each gridfn is stored contiguously.
@@ -136,44 +137,46 @@ public:
{ return N_irho() * N_isigma(); }
// full-grid min/max (don't need sizes)
- int full_grid__min_irho() const { return full_grid__min_irho_; }
- int full_grid__max_irho() const { return full_grid__max_irho_; }
- int full_grid__min_isigma() const { return full_grid__min_isigma_; }
- int full_grid__max_isigma() const { return full_grid__max_isigma_; }
- int full_grid__min_iang(bool want_rho) const
+ int ghosted_grid_min_irho() const { return ghosted_grid_min_irho_; }
+ int ghosted_grid_max_irho() const { return ghosted_grid_max_irho_; }
+ int ghosted_grid_min_isigma() const
+ { return ghosted_grid_min_isigma_; }
+ int ghosted_grid_max_isigma() const
+ { return ghosted_grid_max_isigma_; }
+ int ghosted_grid_min_iang(bool want_rho) const
{
- return want_rho ? full_grid__min_irho()
- : full_grid__min_isigma();
+ return want_rho ? ghosted_grid_min_irho()
+ : ghosted_grid_min_isigma();
}
- int full_grid__max_iang(bool want_rho) const
+ int ghosted_grid_max_iang(bool want_rho) const
{
- return want_rho ? full_grid__max_irho()
- : full_grid__max_isigma();
+ return want_rho ? ghosted_grid_max_irho()
+ : ghosted_grid_max_isigma();
}
- int full_grid__minmax_iang(bool want_min, bool want_rho) const
+ int ghosted_grid_minmax_iang(bool want_min, bool want_rho) const
{
- return want_min ? full_grid__min_iang(want_rho)
- : full_grid__max_iang(want_rho);
+ return want_min ? ghosted_grid_min_iang(want_rho)
+ : ghosted_grid_max_iang(want_rho);
}
// "effective" grid min/max
// (= dynamic select between nominal and full grids)
- int effective__min_irho(bool want_ghost_zones) const
+ int effective_min_irho(bool want_ghost_zones) const
{
- return want_ghost_zones ? full_grid__min_irho() : min_irho();
+ return want_ghost_zones ? ghosted_grid_min_irho() : min_irho();
}
- int effective__max_irho(bool want_ghost_zones) const
+ int effective_max_irho(bool want_ghost_zones) const
{
- return want_ghost_zones ? full_grid__max_irho() : max_irho();
+ return want_ghost_zones ? ghosted_grid_max_irho() : max_irho();
}
- int effective__min_isigma(bool want_ghost_zones) const
+ int effective_min_isigma(bool want_ghost_zones) const
{
- return want_ghost_zones ? full_grid__min_isigma()
+ return want_ghost_zones ? ghosted_grid_min_isigma()
: min_isigma();
}
- int effective__max_isigma(bool want_ghost_zones) const
+ int effective_max_isigma(bool want_ghost_zones) const
{
- return want_ghost_zones ? full_grid__max_isigma()
+ return want_ghost_zones ? ghosted_grid_max_isigma()
: max_isigma();
}
@@ -184,21 +187,21 @@ public:
// ghost zone min/max perpendicular coordinates
int min_rho_ghost_zone__min_iperp() const
- { return full_grid__min_irho(); }
+ { return ghosted_grid_min_irho(); }
int min_rho_ghost_zone__max_iperp() const
{ return min_irho() - 1; }
int max_rho_ghost_zone__min_iperp() const
{ return max_irho() + 1; }
int max_rho_ghost_zone__max_iperp() const
- { return full_grid__max_irho(); }
+ { return ghosted_grid_max_irho(); }
int min_sigma_ghost_zone__min_iperp() const
- { return full_grid__min_isigma(); }
+ { return ghosted_grid_min_isigma(); }
int min_sigma_ghost_zone__max_iperp() const
{ return min_isigma() - 1; }
int max_sigma_ghost_zone__min_iperp() const
{ return max_isigma() + 1; }
int max_sigma_ghost_zone__max_iperp() const
- { return full_grid__max_isigma(); }
+ { return ghosted_grid_max_isigma(); }
int minmax_ang_ghost_zone__min_iperp(bool want_min, bool want_rho) const
{
return want_min
@@ -238,13 +241,13 @@ public:
}
// ... including corners
int rho_ghost_zone_with_corners__min_ipar() const
- { return full_grid__min_isigma(); }
+ { return ghosted_grid_min_isigma(); }
int rho_ghost_zone_with_corners__max_ipar() const
- { return full_grid__max_isigma(); }
+ { return ghosted_grid_max_isigma(); }
int sigma_ghost_zone_with_corners__min_ipar() const
- { return full_grid__min_irho(); }
+ { return ghosted_grid_min_irho(); }
int sigma_ghost_zone_with_corners__max_ipar() const
- { return full_grid__max_irho(); }
+ { return ghosted_grid_max_irho(); }
int ang_ghost_zone_with_corners__min_ipar(bool want_rho) const
{
return want_rho ? rho_ghost_zone_with_corners__min_ipar()
@@ -265,16 +268,16 @@ public:
return (irho >= min_irho()) && (irho <= max_irho())
&& (isigma >= min_isigma()) && (isigma <= max_isigma());
}
- bool is_in_full_grid(int irho, int isigma) const
+ bool is_in_ghosted_grid(int irho, int isigma) const
{
- return (irho >= full_grid__min_irho())
- && (irho <= full_grid__max_irho())
- && (isigma >= full_grid__min_isigma())
- && (isigma <= full_grid__max_isigma());
+ return (irho >= ghosted_grid_min_irho())
+ && (irho <= ghosted_grid_max_irho())
+ && (isigma >= ghosted_grid_min_isigma())
+ && (isigma <= ghosted_grid_max_isigma());
}
bool is_in_ghost_zone(int irho, int isigma) const
{
- return is_in_full_grid(irho, isigma)
+ return is_in_ghosted_grid(irho, isigma)
&& !is_in_nominal_grid(irho, isigma);
}
@@ -324,8 +327,8 @@ private:
const int min_isigma_, max_isigma_;
// full grid min/max bounds
- const int full_grid__min_irho_, full_grid__max_irho_;
- const int full_grid__min_isigma_, full_grid__max_isigma_;
+ const int ghosted_grid_min_irho_, ghosted_grid_max_irho_;
+ const int ghosted_grid_min_isigma_, ghosted_grid_max_isigma_;
};
//******************************************************************************
@@ -461,14 +464,14 @@ public:
{ return want_rho ? max_rho() : max_sigma(); }
// full-grid min/max
- fp full_grid__min_rho() const
- { return rho_of_irho(full_grid__min_irho()); }
- fp full_grid__max_rho() const
- { return rho_of_irho(full_grid__max_irho()); }
- fp full_grid__min_sigma() const
- { return sigma_of_isigma(full_grid__min_isigma()); }
- fp full_grid__max_sigma() const
- { return sigma_of_isigma(full_grid__max_isigma()); }
+ fp ghosted_grid_min_rho() const
+ { return rho_of_irho(ghosted_grid_min_irho()); }
+ fp ghosted_grid_max_rho() const
+ { return rho_of_irho(ghosted_grid_max_irho()); }
+ fp ghosted_grid_min_sigma() const
+ { return sigma_of_isigma(ghosted_grid_min_isigma()); }
+ fp ghosted_grid_max_sigma() const
+ { return sigma_of_isigma(ghosted_grid_max_isigma()); }
//
@@ -33,10 +33,11 @@
// related to those subscripts.
//
-// The grid has a nominal extent, surrounded by a "ghost zone" for
-// finite differencing purposes. For simplicity, all grid functions
-// (gridfns) are stored on the full grid (nominal + ghost zone), even
-// though we actually only need this for finite differencing targets.
+// The grid has a nominal extent, surrounded by "ghost zones" on each
+// side for finite differencing purposes. For simplicity, all grid
+// functions (gridfns) are stored on the full "ghosted" grid (nominal
+// + ghost zones), even though we actually only need this for finite
+// differencing targets.
//
// We identify a gridfn by a small-integer "grid function number",